OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Mensaje incrustado %s",
    "Important mail" : "Correo importante",
    "No message found yet" : "Aún no se encontraron mensajes",
    "Set up an account" : "Configurar una cuenta",
    "Unread mail" : "Correo no leído",
    "Important" : "Importante",
    "Work" : "Trabajo",
    "Personal" : "Personal",
    "To Do" : "Pendiente",
    "Later" : "Después",
    "Mail" : "Correo",
    "You are reaching your mailbox quota limit for {account_email}" : "Está por alcanzar el límite de cuota de su buzón de correo para {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Está actualmente utilizando {percentage} del almacenamiento de su buzón de correo. Por favor, haga algo de espacio eliminando cualquier correo innecesario.",
    "Mail Application" : "Aplicación de correo",
    "Mails" : "Correos",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "La dirección de correo electrónico del remitente: %1$s no se encuentra en el libro de direcciones, pero el nombre del remitente: %2$s se encuentra en el libro de direcciones con el siguiente correo electrónico: %3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "La dirección de correo electrónico del remitente: %1$s no se encuentra en el libro de direcciones, pero el nombre del remitente: %2$s se encuentra en el libro de direcciones con los siguientes correos electrónicos: %3$s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "El remitente está usando una dirección de correo personalizada: %1$s en lugar de su dirección por defecto: %2$s",
    "Sent date is in the future" : "La fecha de envío es en el futuro",
    "Some addresses in this message are not matching the link text" : "Algunas direcciones en este mensaje no coinciden con el texto del enlace",
    "Reply-To email: %1$s  is different from the sender email: %2$s" : "Responder a: %1$s es diferente de la dirección del remitente: %2$s",
    "💌 A mail app for Nextcloud" : "💌 Una aplicación de correo para Nextcloud",
    "Your session has expired. The page will be reloaded." : "Tu sesión ha expirado. La página se recargará.",
    "Drafts are saved in:" : "Los borradores se guardan en:",
    "Sent messages are saved in:" : "Los mensajes enviados se guardan en:",
    "Deleted messages are moved in:" : "Los mensajes eliminados se mueven a:",
    "Archived messages are moved in:" : "Los mensajes archivados se mueven a:",
    "Snoozed messages are moved in:" : "Los mensajes pausados se mueven a:",
    "Junk messages are saved in:" : "Los mensajes \"basura\" se guardan en:",
    "Connecting" : "Conectando",
    "Reconnect Google account" : "Reconectar cuenta de Google",
    "Sign in with Google" : "Iniciar sesión con Google",
    "Reconnect Microsoft account" : "Reconectar cuenta de Microsoft",
    "Sign in with Microsoft" : "Iniciar sesión con Microsoft",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Looking up configuration" : "Buscando configuración",
    "Checking mail host connectivity" : "Comprobando la conectividad del host de correo",
    "Configuration discovery failed. Please use the manual settings" : "Error en el descubrimiento de la configuración. Por favor, usa la configuración manual",
    "Password required" : "Se requiere contraseña",
    "Testing authentication" : "Probando la autenticación",
    "Awaiting user consent" : "Esperando el consentimiento del usuario",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Cuenta creada. Sigue las instrucciones emergentes para vincular tu cuenta de Google",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "Cuenta creada. Sigue las instrucciones emergentes para vincular tu cuenta de Microsoft",
    "Loading account" : "Cargando cuenta",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Cuenta actualizada. Sigue las instrucciones emergentes para reconectar tu cuenta de Google",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Cuenta actualizada. Sigue las instrucciones emergentes para reconectar tu cuenta de Microsoft",
    "Account updated" : "Cuenta actualizada",
    "IMAP server is not reachable" : "El servidor IMAP no es alcanzable",
    "SMTP server is not reachable" : "El servidor SMTP no es alcanzable",
    "IMAP username or password is wrong" : "El nombre de usuario o la contraseña IMAP son incorrectos",
    "SMTP username or password is wrong" : "El nombre de usuario o la contraseña SMTP son incorrectos",
    "IMAP connection failed" : "Falló la conexión IMAP",
    "SMTP connection failed" : "Falló la conexión SMTP",
    "Authorization pop-up closed" : "La ventana emergente de autorización fue cerrada",
    "Configuration discovery temporarily not available. Please try again later." : "Descubrimiento de configuración no disponible temporalmente. Por favor intenta más tarde.",
    "There was an error while setting up your account" : "Hubo un error al configurar tu cuenta",
    "Auto" : "Auto",
    "Name" : "Nombre",
    "Mail address" : "Dirección de correo",
    "name@example.org" : "nombre@ejemplo.org",
    "Please enter an email of the format name@example.com" : "Por favor, ingresa un correo electrónico en el formato nombre@ejemplo.com",
    "Password" : "Contraseña",
    "Manual" : "Manual",
    "IMAP Settings" : "Configuración IMAP",
    "IMAP Host" : "Servidor IMAP",
    "IMAP Security" : "Seguridad IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Settings" : "Configuración SMTP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Security" : "Seguridad SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Para que la cuenta de Google funcione con esta aplicación, debes habilitar la autenticación en dos pasos para Google y generar una contraseña de aplicación.",
    "Account settings" : "Configuración de la cuenta",
    "Aliases" : "Aliases",
    "Alias to S/MIME certificate mapping" : "Asignación de alias a certificados S/MIME",
    "Signature" : "Firma",
    "A signature is added to the text of new messages and replies." : "Se agrega una firma al texto de nuevos mensajes y respuestas.",
    "Writing mode" : "Modo de escritura",
    "Preferred writing mode for new messages and replies." : "Modo de escritura preferido para nuevos mensajes y respuestas.",
    "Default folders" : "Carpetas predeterminadas",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Las carpetas para borradores, mensajes enviados, mensajes borrados, mensajes archivados y mensajes \"basura\".",
    "Automatic trash deletion" : "Borrado automatizado de papelera",
    "Days after which messages in Trash will automatically be deleted:" : "Días tras los cuales se borrarán automáticamente los mensajes de la papelera",
    "Autoresponder" : "Respuesta automática",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Respuesta automática a mensajes entrantes. Si alguien te envía varios mensajes, esta respuesta automática se enviará como máximo una vez cada 4 días.",
    "Filters" : "Filtros",
    "Sieve script editor" : "Editor de scripts Sieve",
    "Mail server" : "Servidor de correo",
    "Sieve server" : "Servidor Sieve",
    "Update alias" : "Actualizar alias",
    "Rename alias" : "Renombrar alias",
    "Show update alias form" : "Mostrar formulario de actualización de alias",
    "Delete alias" : "Eliminar alias",
    "Go back" : "Regresar",
    "Change name" : "Cambiar nombre",
    "Email address" : "Dirección de correo electrónico",
    "Add alias" : "Añadir alias",
    "Create alias" : "Crear alias",
    "Cancel" : "Cancelar",
    "Search in the body of messages in priority Inbox" : "Busca en el cuerpo de los mensajes de la bandeja de entrada prioritaria",
    "Activate" : "Activar",
    "Put my text to the bottom of a reply instead of on top of it." : "Pon el texto al fondo de una respuesta, en lugar de arriba.",
    "Mark as important" : "Marcar como importante",
    "Remind about messages that require a reply but received none" : "Recordar mensajes que requieren una respuesta pero no han recibido ninguna",
    "Use internal addresses" : "Usar direcciones internas",
    "Could not update preference" : "No se pudo actualizar la preferencia",
    "Mail settings" : "Configuración de correo",
    "Accounts" : "Cuentas",
    "Add mail account" : "Agregar cuenta de correo",
    "Settings for:" : "Configuraciones para:",
    "General" : "General",
    "Layout" : "Disposición",
    "List" : "Lista",
    "Vertical split" : "División vertical",
    "Horizontal split" : "División horizontal",
    "Sorting" : "Ordenando",
    "Newest" : "Más recientes",
    "Oldest" : "Más antiguo",
    "Search in body" : "Buscar cuerpo",
    "Reply text position" : "Posisión de respuesta del texto",
    "Gravatar settings" : "Ajustes de Gravatar",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Mailto" : "Mailto",
    "Register as application for mail links" : "Registrar como aplicación para enlaces de correo electrónico",
    "Register" : "Registrar",
    "Privacy and security" : "Privacidad y seguridad",
    "Data collection consent" : "Consentimiento de recolección de datos",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
    "Trusted senders" : "Remitentes de confianza",
    "Internal addresses" : "Direcciones internas",
    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Resalta direcciones de correo electrónico externas al activar esta característica, administra tus direcciones internas y dominios para asegurar que los contactos reconocidos permanezcan sin resaltar.",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
    "Mailvelope" : "Mailvelope",
    "Mailvelope is enabled for the current domain!" : "¡Mailvelope se encuentra habilitado para el dominio actual!",
    "Looking for a way to encrypt your emails?" : "¿Buscas una forma de cifrar tus correos electrónicos?",
    "Install Mailvelope browser extension by clicking here" : "Instala la extensión del navegador Mailvelope haciendo clic aquí",
    "Enable Mailvelope for the current domain" : "Habilita Mailvelope para el dominio actual",
    "Assistance features" : "Características de asistencia",
    "About" : "Acerca",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Archive" : "Archivar",
    "Delete" : "Borrar",
    "Search" : "Buscar",
    "Send" : "Enviar",
    "Refresh" : "Actualizar",
    "No certificate" : "Sin certificado",
    "Certificate updated" : "Certificado actualizado",
    "Could not update certificate" : "No se pudo actualizar el certificado",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Válido hasta {expiryDate}",
    "Select an alias" : "Selecciona un alias",
    "Select certificates" : "Selecciona certificados",
    "Update Certificate" : "Actualizar certificado",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "El certificado seleccionado no es de confianza para el servidor. Los destinatarios podrían no ser capaces de verificar tu firma.",
    "Encrypt with S/MIME and send later" : "Encriptar con S/MIME y enviar más tarde",
    "Encrypt with S/MIME and send" : "Encriptar con S/MIME y enviar",
    "Encrypt with Mailvelope and send later" : "Encriptar con Mailvelope y enviar más tarde",
    "Encrypt with Mailvelope and send" : "Encriptar con Mailvelope y enviar",
    "Send later" : "Enviar más tarde",
    "Message {id} could not be found" : "No se pudo encontrar el mensaje {id}",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Se seleccionó Firmar o Encriptar con S/MIME, pero no tenemos un certificado para el alias seleccionado. El mensaje no sera firmado ni encriptado.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Cualquier formato existente (por ejemplo, negrita, cursiva, subrayado o imágenes en línea) se eliminará.",
    "Turn off formatting" : "Desactivar formato",
    "Turn off and remove formatting" : "Desactivar y remover formato",
    "Keep formatting" : "Conservar formato",
    "From" : "De",
    "Select account" : "Selecciona la cuenta",
    "To" : "Para",
    "Cc/Bcc" : "Cc/Cco",
    "Select recipient" : "Seleccionar destinatario",
    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
    "Cc" : "Cc",
    "Bcc" : "Cco",
    "Subject" : "Asunto",
    "Subject …" : "Asunto...",
    "This message came from a noreply address so your reply will probably not be read." : "Este mensaje vino de una dirección \"no-responder\", por lo que tu respuesta podría no ser leída.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Los siguientes destinatarios no tienen un certificado S/MIME: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Los siguientes destinatarios no tienen una clave PGP: {recipients}.",
    "Write message …" : "Redactar mensaje...",
    "Saving draft …" : "Guardando borrador...",
    "Error saving draft" : "Error guardando el borrador",
    "Draft saved" : "Borrador guardado",
    "Save draft" : "Guardar borrador",
    "Discard & close draft" : "Descartar y cerrar borrador",
    "Enable formatting" : "Activar formato",
    "Disable formatting" : "Desactivar formato",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Add share link from Files" : "Agregar un enlace adjunto desde Archivos",
    "Smart picker" : "Selector inteligente",
    "Request a read receipt" : "Solicitar confirmación de lectura",
    "Sign message with S/MIME" : "Firmar mensaje con S/MIME",
    "Encrypt message with S/MIME" : "Encriptar mensaje con S/MIME",
    "Encrypt message with Mailvelope" : "Encriptar mensaje con Mailvelope",
    "Send now" : "Enviar ahora",
    "Tomorrow morning" : "Mañana por la mañana",
    "Tomorrow afternoon" : "Mañana por la tarde",
    "Monday morning" : "Lunes por la mañana",
    "Custom date and time" : "Fecha y hora personalizada",
    "Enter a date" : "Ingrese una fecha",
    "Choose" : "Seleccionar",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Choose a file to share as a link" : "Eligir un archivo para compartir como enlace",
    "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
    "Untitled message" : "Mensaje sin título",
    "Expand composer" : "Expandir redactor",
    "Close composer" : "Cerrar redactor",
    "Confirm" : "Confirmar",
    "Tag: {name} deleted" : "Etiqueta: {name} eliminada",
    "An error occurred, unable to delete the tag." : "Ha ocurrido un error, no se ha podido eliminar la etiqueta.",
    "The tag will be deleted from all messages." : "La etiqueta se eliminará de todos los mensajes.",
    "Plain text" : "Texto plano",
    "Rich text" : "Texto enriquecido",
    "No messages in this folder" : "No hay mensajes en esta carpeta",
    "No messages" : "Sin mensajes",
    "Blind copy recipients only" : "Solo destinatarios de copia oculta",
    "No subject" : "Sin asunto",
    "Set reminder for later today" : "Configurar recordatorio para hoy, más tarde",
    "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
    "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
    "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
    "Could not delete message" : "No se pudo eliminar el mensaje",
    "Could not archive message" : "No se pudo archivar el mensaje",
    "Thread was snoozed" : "El hilo ha sido pausado",
    "Could not snooze thread" : "No se ha podido pausar el hilo",
    "Thread was unsnoozed" : "El hilo fue reanudado",
    "Could not unsnooze thread" : "No se pudo reanudar el hilo",
    "Encrypted message" : "Mensaje encriptado",
    "This message is unread" : "Este mensaje no ha sido leído",
    "Unfavorite" : "Quitar favorito",
    "Favorite" : "Marcar como favorito",
    "Unread" : "No leído",
    "Read" : "Leer",
    "Unimportant" : "Sin importancia",
    "Mark not spam" : "Marcar como no spam",
    "Mark as spam" : "Marcar como spam",
    "Edit tags" : "Editar etiquetas",
    "Snooze" : "Pausar",
    "Unsnooze" : "Reanudar",
    "Move thread" : "Mover hilo",
    "Archive thread" : "Archivar hilo",
    "Delete thread" : "Eliminar hilo",
    "More actions" : "Más acciones",
    "Back" : "Atrás",
    "Set custom snooze" : "Configurar pausa personalizada",
    "Edit as new message" : "Editar como nuevo mensaje",
    "Create event" : "Crear evento",
    "Create task" : "Crear tarea",
    "Download message" : "Descargar mensaje",
    "Load more" : "Cargar más",
    "Report this bug" : "Reportar este bug",
    "Event created" : "Evento creado",
    "Could not create event" : "No se pudo crear el evento",
    "All day" : "Todo el día",
    "Select calendar" : "Seleccionar calendario",
    "Description" : "Descripción",
    "Create" : "Crear",
    "This event was updated" : "Este evento fue actualizado",
    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó tu invitación",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó tentativamente tu invitación",
    "{attendeeName} declined your invitation" : "{attendeeName} rechazó tu invitación",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reaccionó a tu invitación",
    "Failed to save your participation status" : "Error al guardar tu estado de participación",
    "You accepted this invitation" : "Has aceptado esta invitación",
    "You tentatively accepted this invitation" : "Has aceptado tentativamente esta invitación",
    "You declined this invitation" : "Has rechazado esta invitación",
    "You already reacted to this invitation" : "Ya has reaccionado a esta invitación",
    "You have been invited to an event" : "Has sido invitado a un evento",
    "This event was cancelled" : "Este evento fue cancelado",
    "Save to" : "Guardar en",
    "Select" : "Seleccionar",
    "Comment" : "Comentario",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Tentatively accept" : "Aceptar tentativamente",
    "More options" : "Más opciones",
    "Could not remove internal address {sender}" : "No se pudo remover la dirección interna {sender}",
    "Could not add internal address {address}" : "No se pudo agregar la dirección interna {address}",
    "individual" : "individual",
    "domain" : "dominio",
    "Remove" : "Eliminar",
    "email" : "correo electrónico",
    "Add internal address" : "Agregar dirección interna",
    "Add internal email or domain" : "Agregar dirección de correo interna o dominio",
    "Itinerary for {type} is not supported yet" : "El itinerario para {type} aún no es soportado",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivado y/o eliminar este mensaje de la carpeta actual",
    "Loading messages …" : "Cargando mensajes...",
    "Choose target folder" : "Elegir carpeta destino",
    "No more submailboxes in here" : "No hay más sub-buzones aquí",
    "Follow up" : "Seguimiento",
    "Follow up info" : "Información de seguimiento",
    "Important info" : "Información importante",
    "Other" : "Otro",
    "Forward" : "Adelante",
    "Translate" : "Traducir",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Save all to Files" : "Guardar todo a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "Quoted text" : "Texto citado",
    "Move" : "Mover",
    "Loading …" : "Cargando …",
    "Remove account" : "Eliminar cuenta",
    "Quota" : "Cuota",
    "Saving" : "Guardando",
    "Move up" : "Mover arriba",
    "Move down" : "Mover abajo",
    "Show all folders" : "Mostrar todas las carpetas",
    "Delete folder" : "Eliminar carpeta",
    "Mark all as read" : "Marcar todos como leídos",
    "Rename" : "Renombrar",
    "Move folder" : "Mover carpeta",
    "Clear cache" : "Borrar el caché",
    "Subscribed" : "Suscrito",
    "New message" : "Mensaje nuevo",
    "Reply" : "Responder",
    "Retry" : "Reintentar",
    "First day" : "Primer día",
    "Message" : "Mensaje",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Add" : "Agregar",
    "Show less" : "Mostrar menos",
    "Show more" : "Mostrar más",
    "Clear" : "Limpiar",
    "Close" : "Cerrar",
    "Date" : "Fecha",
    "Tags" : "Etiquetas",
    "Select tags" : "Selecciona las etiquetas",
    "Last 7 days" : "Últimos 7 días",
    "Custom" : "Personalizado",
    "Tag already exists" : "La etiqueta ya existe",
    "Add tag" : "Añadir etiqueta",
    "Not found" : "No encontrado",
    "Translate from" : "Traducir desde",
    "Untitled event" : "Evento sin título",
    "(organizer)" : "(organizador)",
    "Recipient" : "Destinatario",
    "Operator" : "Operador",
    "contains" : "contiene",
    "matches" : "coincide",
    "Priority" : "Prioridad",
    "Reset" : "Reiniciar",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Valid until" : "Válido hasta",
    "Certificate" : "Certificado",
    "Submit" : "Enviar",
    "Account connected" : "Cuenta conectada",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "All" : "Todos",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Papelera",
    "Error while sharing file" : "Error al compartir el archivo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "Continue to %s" : "Continuar a %s",
    "Mailbox search" : "Búsqueda en el buzón de correo",
    "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
    "Draft: " : "Borrador:",
    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
    "Could not open mailbox" : "No se pudo abrir el buzón",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indizando tus mensajes. Esto puede tardar un poco para buzones grandes.",
    "Choose target mailbox" : "Escoger buzón de destino",
    "Clear mailbox" : "Vaciar buzón",
    "Actions" : "Acciones"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
